#!/bin/sh
# Control mpc/mpd from our icewm menu
# 06.20.2013 by Nathan Fisher (nfisher dot sr at gmail)
#
# There exist already a few such scripts, many of which work quite well.
# However, none that I am aware of are written as simple shell scripts,
# most use Python. I'm writing this for those who want this type of
# functionality on a more cutdown system that may not have higher level
# interpreters available.
#
# This script, in comparison, requires only mpd, mpc, and a bourne
# compatible shell. It's also useful to have another client program
# installed so we can launch it from this menu.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#

########################################################################
# User configuration section
#
# The host we want to connect to. Most people will choose the default
# (localhost).
MPD_HOST=localhost
# The port our mpd server is running on. Again, the default is normally
# correct.
MPD_PORT=6600
# The client program we want to be able to launch from this menu.
MPD_CLIENT="ncmpc"
# If you are using a cli client, set this to your preferred terminal
# Don't forget the '-e' or whatever to make it open the specified program
# If you are using a gui client comment this line out
CLIENT_TERMINAL="xterm -e"
# The name of your icon theme
ICON_THEME=gnome
# Path to your icons
ICON_PATH=/usr/share/icons
#
########################################################################

export MPD_HOST MPD_PORT MPD_CLIENT

REPEAT_STATUS=$(mpc | tail -n 1 | cut -f 3 -d ':' | cut -f 2 -d ' ')
RANDOM_STATUS=$(mpc | tail -n 1 | cut -f 4 -d ':' | cut -f 2 -d ' ')

MPD_PLAY="prog Play media-playback-start mpc play"
MPD_PAUSE="prog Pause media-playback-pause mpc pause"
MPD_STOP="prog Stop media-playback-stop mpc stop"
MPD_OTHER="prog Previous actions/media-skip-backward mpc prev
prog Next media-skip-forward mpc next
separator
prog \"Toggle Repeat [${REPEAT_STATUS}]\" media-playlist-repeat mpc repeat
prog \"Toggle Random [${RANDOM_STATUS}]\" media-playlist-shuffle mpc random"

MPD_CURRENT=$(mpc current)
if [ "$MPD_CURRENT" = "" ] ; then
 MPD_MSG="Stopped"
 MPD_STATE=stopped
 MPD_ICON="media-playback-stop"
 CONTROLS="${MPD_PLAY}"
else
 if [ "$(mpc | grep 'paused')" = "" ] ; then
  MPD_STATE=playing
  MPD_ICON="media-playback-start"
  CONTROLS="${MPD_PAUSE}
${MPD_STOP}
${MPD_OTHER}"
 else
  MPD_STATE=paused
  MPD_ICON="media-playback-pause"
  CONTROLS="${MPD_PLAY}
${MPD_OTHER}"
 fi
 MPD_MSG="$MPD_CURRENT [$MPD_STATE]"
fi

cat << EOF
prog "$MPD_MSG" ${MPD_ICON} ${CLIENT_TERMINAL} ${MPD_CLIENT}
separator
menu "$(mpc volume | sed 's/ 0%/ [muted]/')" multimedia-volume-control {
 prog '100%' - mpc volume 100
 prog '85%' - mpc volume 85
 prog '70%' - mpc volume 70
 prog '55%' - mpc volume 55
 prog '40%' - mpc volume 40
 prog '25%' - mpc volume 25
 prog '15%' - mpc volume 15
 separator
 prog "mute" audio-volume-muted mpc volume 0
}
menu "Playlist" text-x-generic {
EOF
# Populate the playlist submenu
mpc lsplaylists | while read playlist
do
 cat << EOF
 prog "${playlist}" - load ${playlist}
EOF
done
cat << EOF
 separator
 prog "Clear" edit-clear mpc clear
}
separator
$CONTROLS
separator
prog "Update Database" view-refresh mpc refresh
}
EOF
